@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-02-21'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2015-03-08'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -270,6 +270,8 @@ sub _process_script {
             my $summary = $sc_spec->{summary} // $meta->{summary};
             push @content, "$summary.\n\n" if $summary;
 
+            next if $sc_spec->{is_alias};
+
             my $description = $sc_spec->{description} // $meta->{description};
             if ($description) {
                 push @content,
@@ -320,12 +322,15 @@ sub _process_script {
 
             # display each subcommand's options (without the common options)
             for my $sc_name (@sc_names) {
+                my $sc_spec = $cli->{subcommands}{$sc_name};
+                next if $sc_spec->{is_alias};
                 my $opts = $clidocdata{$sc_name}{opts};
                 my @opts = sort {
                     (my $a_without_dash = $a) =~ s/^-+//;
                     (my $b_without_dash = $b) =~ s/^-+//;
                     lc($a) cmp lc($b);
                 } grep {!$check_common_arg->($opts, $_)} keys %$opts;
+                next unless @opts;
                 push @content, "=head2 Options for subcommand $sc_name\n\n";
                 push @content, "=over\n\n";
                 for (@opts) {
@@ -463,7 +468,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.32 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-02-21.
+This document describes version 0.33 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-03-08.
 
 =head1 SYNOPSIS
 
@@ -560,7 +565,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
 
 =head1 BUGS
 
